@@ -1,19 +1,20 @@
 import sys
 
+
 def print_info() -> None:
     print(
-        "Type annotations for boto3.CodeArtifact 1.17.56\n"
-        "Version:         1.17.56.0\n"
-        "Builder version: 4.6.0\n"
+        "Type annotations for boto3.CodeArtifact 1.17.69\n"
+        "Version:         1.17.69.0.post1\n"
+        "Builder version: 4.12.0\n"
         "Docs:            https://pypi.org/project/mypy-boto3-codeartifact/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.56.0")
+    print("1.17.69.0.post1")
 
 
 def main() -> None:
