@@ -1,5 +1,7 @@
 """
-Main interface for codeartifact service client
+Type annotations for codeartifact service client.
+
+[Open documentation](./client.md)
 
 Usage::
 
@@ -23,7 +25,9 @@ from mypy_boto3_codeartifact.paginator import (
     ListRepositoriesInDomainPaginator,
     ListRepositoriesPaginator,
 )
-from mypy_boto3_codeartifact.type_defs import (
+
+from .literals import PackageFormat, PackageVersionStatus
+from .type_defs import (
     AssociateExternalConnectionResultTypeDef,
     CopyPackageVersionsResultTypeDef,
     CreateDomainResultTypeDef,
@@ -90,7 +94,8 @@ class Exceptions:
 
 class CodeArtifactClient:
     """
-    [CodeArtifact.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -100,12 +105,14 @@ class CodeArtifactClient:
         self, domain: str, repository: str, externalConnection: str, domainOwner: str = None
     ) -> AssociateExternalConnectionResultTypeDef:
         """
-        [Client.associate_external_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.associate_external_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.associate_external_connection)
+        [Show boto3-stubs documentation](./client.md#associate-external-connection)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can-paginate)
         """
 
     def copy_package_versions(
@@ -113,7 +120,7 @@ class CodeArtifactClient:
         domain: str,
         sourceRepository: str,
         destinationRepository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
+        format: PackageFormat,
         package: str,
         domainOwner: str = None,
         namespace: str = None,
@@ -123,14 +130,16 @@ class CodeArtifactClient:
         includeFromUpstream: bool = None,
     ) -> CopyPackageVersionsResultTypeDef:
         """
-        [Client.copy_package_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.copy_package_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.copy_package_versions)
+        [Show boto3-stubs documentation](./client.md#copy-package-versions)
         """
 
     def create_domain(
         self, domain: str, encryptionKey: str = None, tags: List["TagTypeDef"] = None
     ) -> CreateDomainResultTypeDef:
         """
-        [Client.create_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.create_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.create_domain)
+        [Show boto3-stubs documentation](./client.md#create-domain)
         """
 
     def create_repository(
@@ -143,101 +152,108 @@ class CodeArtifactClient:
         tags: List["TagTypeDef"] = None,
     ) -> CreateRepositoryResultTypeDef:
         """
-        [Client.create_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.create_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.create_repository)
+        [Show boto3-stubs documentation](./client.md#create-repository)
         """
 
     def delete_domain(self, domain: str, domainOwner: str = None) -> DeleteDomainResultTypeDef:
         """
-        [Client.delete_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain)
+        [Show boto3-stubs documentation](./client.md#delete-domain)
         """
 
     def delete_domain_permissions_policy(
         self, domain: str, domainOwner: str = None, policyRevision: str = None
     ) -> DeleteDomainPermissionsPolicyResultTypeDef:
         """
-        [Client.delete_domain_permissions_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain_permissions_policy)
+        [Show boto3-stubs documentation](./client.md#delete-domain-permissions-policy)
         """
 
     def delete_package_versions(
         self,
         domain: str,
         repository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
+        format: PackageFormat,
         package: str,
         versions: List[str],
         domainOwner: str = None,
         namespace: str = None,
-        expectedStatus: Literal[
-            "Published", "Unfinished", "Unlisted", "Archived", "Disposed", "Deleted"
-        ] = None,
+        expectedStatus: PackageVersionStatus = None,
     ) -> DeletePackageVersionsResultTypeDef:
         """
-        [Client.delete_package_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.delete_package_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.delete_package_versions)
+        [Show boto3-stubs documentation](./client.md#delete-package-versions)
         """
 
     def delete_repository(
         self, domain: str, repository: str, domainOwner: str = None
     ) -> DeleteRepositoryResultTypeDef:
         """
-        [Client.delete_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository)
+        [Show boto3-stubs documentation](./client.md#delete-repository)
         """
 
     def delete_repository_permissions_policy(
         self, domain: str, repository: str, domainOwner: str = None, policyRevision: str = None
     ) -> DeleteRepositoryPermissionsPolicyResultTypeDef:
         """
-        [Client.delete_repository_permissions_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository_permissions_policy)
+        [Show boto3-stubs documentation](./client.md#delete-repository-permissions-policy)
         """
 
     def describe_domain(self, domain: str, domainOwner: str = None) -> DescribeDomainResultTypeDef:
         """
-        [Client.describe_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.describe_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.describe_domain)
+        [Show boto3-stubs documentation](./client.md#describe-domain)
         """
 
     def describe_package_version(
         self,
         domain: str,
         repository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
+        format: PackageFormat,
         package: str,
         packageVersion: str,
         domainOwner: str = None,
         namespace: str = None,
     ) -> DescribePackageVersionResultTypeDef:
         """
-        [Client.describe_package_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.describe_package_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.describe_package_version)
+        [Show boto3-stubs documentation](./client.md#describe-package-version)
         """
 
     def describe_repository(
         self, domain: str, repository: str, domainOwner: str = None
     ) -> DescribeRepositoryResultTypeDef:
         """
-        [Client.describe_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.describe_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.describe_repository)
+        [Show boto3-stubs documentation](./client.md#describe-repository)
         """
 
     def disassociate_external_connection(
         self, domain: str, repository: str, externalConnection: str, domainOwner: str = None
     ) -> DisassociateExternalConnectionResultTypeDef:
         """
-        [Client.disassociate_external_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.disassociate_external_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.disassociate_external_connection)
+        [Show boto3-stubs documentation](./client.md#disassociate-external-connection)
         """
 
     def dispose_package_versions(
         self,
         domain: str,
         repository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
+        format: PackageFormat,
         package: str,
         versions: List[str],
         domainOwner: str = None,
         namespace: str = None,
         versionRevisions: Dict[str, str] = None,
-        expectedStatus: Literal[
-            "Published", "Unfinished", "Unlisted", "Archived", "Disposed", "Deleted"
-        ] = None,
+        expectedStatus: PackageVersionStatus = None,
     ) -> DisposePackageVersionsResultTypeDef:
         """
-        [Client.dispose_package_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.dispose_package_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.dispose_package_versions)
+        [Show boto3-stubs documentation](./client.md#dispose-package-versions)
         """
 
     def generate_presigned_url(
@@ -248,28 +264,31 @@ class CodeArtifactClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
         """
 
     def get_authorization_token(
         self, domain: str, domainOwner: str = None, durationSeconds: int = None
     ) -> GetAuthorizationTokenResultTypeDef:
         """
-        [Client.get_authorization_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.get_authorization_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.get_authorization_token)
+        [Show boto3-stubs documentation](./client.md#get-authorization-token)
         """
 
     def get_domain_permissions_policy(
         self, domain: str, domainOwner: str = None
     ) -> GetDomainPermissionsPolicyResultTypeDef:
         """
-        [Client.get_domain_permissions_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.get_domain_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.get_domain_permissions_policy)
+        [Show boto3-stubs documentation](./client.md#get-domain-permissions-policy)
         """
 
     def get_package_version_asset(
         self,
         domain: str,
         repository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
+        format: PackageFormat,
         package: str,
         packageVersion: str,
         asset: str,
@@ -278,53 +297,54 @@ class CodeArtifactClient:
         packageVersionRevision: str = None,
     ) -> GetPackageVersionAssetResultTypeDef:
         """
-        [Client.get_package_version_asset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_asset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_asset)
+        [Show boto3-stubs documentation](./client.md#get-package-version-asset)
         """
 
     def get_package_version_readme(
         self,
         domain: str,
         repository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
+        format: PackageFormat,
         package: str,
         packageVersion: str,
         domainOwner: str = None,
         namespace: str = None,
     ) -> GetPackageVersionReadmeResultTypeDef:
         """
-        [Client.get_package_version_readme documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_readme)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_readme)
+        [Show boto3-stubs documentation](./client.md#get-package-version-readme)
         """
 
     def get_repository_endpoint(
-        self,
-        domain: str,
-        repository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
-        domainOwner: str = None,
+        self, domain: str, repository: str, format: PackageFormat, domainOwner: str = None
     ) -> GetRepositoryEndpointResultTypeDef:
         """
-        [Client.get_repository_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_endpoint)
+        [Show boto3-stubs documentation](./client.md#get-repository-endpoint)
         """
 
     def get_repository_permissions_policy(
         self, domain: str, repository: str, domainOwner: str = None
     ) -> GetRepositoryPermissionsPolicyResultTypeDef:
         """
-        [Client.get_repository_permissions_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_permissions_policy)
+        [Show boto3-stubs documentation](./client.md#get-repository-permissions-policy)
         """
 
     def list_domains(
         self, maxResults: int = None, nextToken: str = None
     ) -> ListDomainsResultTypeDef:
         """
-        [Client.list_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.list_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.list_domains)
+        [Show boto3-stubs documentation](./client.md#list-domains)
         """
 
     def list_package_version_assets(
         self,
         domain: str,
         repository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
+        format: PackageFormat,
         package: str,
         packageVersion: str,
         domainOwner: str = None,
@@ -333,14 +353,15 @@ class CodeArtifactClient:
         nextToken: str = None,
     ) -> ListPackageVersionAssetsResultTypeDef:
         """
-        [Client.list_package_version_assets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_assets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_assets)
+        [Show boto3-stubs documentation](./client.md#list-package-version-assets)
         """
 
     def list_package_version_dependencies(
         self,
         domain: str,
         repository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
+        format: PackageFormat,
         package: str,
         packageVersion: str,
         domainOwner: str = None,
@@ -348,26 +369,26 @@ class CodeArtifactClient:
         nextToken: str = None,
     ) -> ListPackageVersionDependenciesResultTypeDef:
         """
-        [Client.list_package_version_dependencies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_dependencies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_dependencies)
+        [Show boto3-stubs documentation](./client.md#list-package-version-dependencies)
         """
 
     def list_package_versions(
         self,
         domain: str,
         repository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
+        format: PackageFormat,
         package: str,
         domainOwner: str = None,
         namespace: str = None,
-        status: Literal[
-            "Published", "Unfinished", "Unlisted", "Archived", "Disposed", "Deleted"
-        ] = None,
+        status: PackageVersionStatus = None,
         sortBy: Literal["PUBLISHED_TIME"] = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListPackageVersionsResultTypeDef:
         """
-        [Client.list_package_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.list_package_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.list_package_versions)
+        [Show boto3-stubs documentation](./client.md#list-package-versions)
         """
 
     def list_packages(
@@ -375,21 +396,23 @@ class CodeArtifactClient:
         domain: str,
         repository: str,
         domainOwner: str = None,
-        format: Literal["npm", "pypi", "maven", "nuget"] = None,
+        format: PackageFormat = None,
         namespace: str = None,
         packagePrefix: str = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListPackagesResultTypeDef:
         """
-        [Client.list_packages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.list_packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.list_packages)
+        [Show boto3-stubs documentation](./client.md#list-packages)
         """
 
     def list_repositories(
         self, repositoryPrefix: str = None, maxResults: int = None, nextToken: str = None
     ) -> ListRepositoriesResultTypeDef:
         """
-        [Client.list_repositories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories)
+        [Show boto3-stubs documentation](./client.md#list-repositories)
         """
 
     def list_repositories_in_domain(
@@ -402,19 +425,22 @@ class CodeArtifactClient:
         nextToken: str = None,
     ) -> ListRepositoriesInDomainResultTypeDef:
         """
-        [Client.list_repositories_in_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories_in_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories_in_domain)
+        [Show boto3-stubs documentation](./client.md#list-repositories-in-domain)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResultTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
         """
 
     def put_domain_permissions_policy(
         self, domain: str, policyDocument: str, domainOwner: str = None, policyRevision: str = None
     ) -> PutDomainPermissionsPolicyResultTypeDef:
         """
-        [Client.put_domain_permissions_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.put_domain_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.put_domain_permissions_policy)
+        [Show boto3-stubs documentation](./client.md#put-domain-permissions-policy)
         """
 
     def put_repository_permissions_policy(
@@ -426,38 +452,38 @@ class CodeArtifactClient:
         policyRevision: str = None,
     ) -> PutRepositoryPermissionsPolicyResultTypeDef:
         """
-        [Client.put_repository_permissions_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.put_repository_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.put_repository_permissions_policy)
+        [Show boto3-stubs documentation](./client.md#put-repository-permissions-policy)
         """
 
     def tag_resource(self, resourceArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag-resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag-resource)
         """
 
     def update_package_versions_status(
         self,
         domain: str,
         repository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
+        format: PackageFormat,
         package: str,
         versions: List[str],
-        targetStatus: Literal[
-            "Published", "Unfinished", "Unlisted", "Archived", "Disposed", "Deleted"
-        ],
+        targetStatus: PackageVersionStatus,
         domainOwner: str = None,
         namespace: str = None,
         versionRevisions: Dict[str, str] = None,
-        expectedStatus: Literal[
-            "Published", "Unfinished", "Unlisted", "Archived", "Disposed", "Deleted"
-        ] = None,
+        expectedStatus: PackageVersionStatus = None,
     ) -> UpdatePackageVersionsStatusResultTypeDef:
         """
-        [Client.update_package_versions_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.update_package_versions_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.update_package_versions_status)
+        [Show boto3-stubs documentation](./client.md#update-package-versions-status)
         """
 
     def update_repository(
@@ -469,13 +495,14 @@ class CodeArtifactClient:
         upstreams: List[UpstreamRepositoryTypeDef] = None,
     ) -> UpdateRepositoryResultTypeDef:
         """
-        [Client.update_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Client.update_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Client.update_repository)
+        [Show boto3-stubs documentation](./client.md#update-repository)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_domains"]) -> ListDomainsPaginator:
         """
-        [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListDomains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListDomains)[Show boto3-stubs documentation](./paginators.md#listdomainspaginator)
         """
 
     @overload
@@ -483,7 +510,7 @@ class CodeArtifactClient:
         self, operation_name: Literal["list_package_version_assets"]
     ) -> ListPackageVersionAssetsPaginator:
         """
-        [Paginator.ListPackageVersionAssets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersionAssets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersionAssets)[Show boto3-stubs documentation](./paginators.md#listpackageversionassetspaginator)
         """
 
     @overload
@@ -491,13 +518,13 @@ class CodeArtifactClient:
         self, operation_name: Literal["list_package_versions"]
     ) -> ListPackageVersionsPaginator:
         """
-        [Paginator.ListPackageVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersions)[Show boto3-stubs documentation](./paginators.md#listpackageversionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_packages"]) -> ListPackagesPaginator:
         """
-        [Paginator.ListPackages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackages)[Show boto3-stubs documentation](./paginators.md#listpackagespaginator)
         """
 
     @overload
@@ -505,7 +532,7 @@ class CodeArtifactClient:
         self, operation_name: Literal["list_repositories"]
     ) -> ListRepositoriesPaginator:
         """
-        [Paginator.ListRepositories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositories)[Show boto3-stubs documentation](./paginators.md#listrepositoriespaginator)
         """
 
     @overload
@@ -513,5 +540,5 @@ class CodeArtifactClient:
         self, operation_name: Literal["list_repositories_in_domain"]
     ) -> ListRepositoriesInDomainPaginator:
         """
-        [Paginator.ListRepositoriesInDomain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositoriesInDomain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositoriesInDomain)[Show boto3-stubs documentation](./paginators.md#listrepositoriesindomainpaginator)
         """
