@@ -1,5 +1,7 @@
 """
-Main interface for codeartifact service client paginators.
+Type annotations for codeartifact service client paginators.
+
+[Open documentation](./paginators.md)
 
 Usage::
 
@@ -31,7 +33,8 @@ from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_codeartifact.type_defs import (
+from .literals import PackageFormat, PackageVersionStatus
+from .type_defs import (
     ListDomainsResultTypeDef,
     ListPackagesResultTypeDef,
     ListPackageVersionAssetsResultTypeDef,
@@ -59,27 +62,28 @@ __all__ = (
 
 class ListDomainsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListDomains)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListDomains)[Show boto3-stubs documentation](./paginators.md#listdomainspaginator)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDomainsResultTypeDef]:
         """
-        [ListDomains.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListDomains.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListDomains.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listdomainspaginator)
         """
 
 
 class ListPackageVersionAssetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListPackageVersionAssets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersionAssets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersionAssets)[Show boto3-stubs documentation](./paginators.md#listpackageversionassetspaginator)
     """
 
     def paginate(
         self,
         domain: str,
         repository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
+        format: PackageFormat,
         package: str,
         packageVersion: str,
         domainOwner: str = None,
@@ -87,37 +91,37 @@ class ListPackageVersionAssetsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListPackageVersionAssetsResultTypeDef]:
         """
-        [ListPackageVersionAssets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersionAssets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersionAssets.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listpackageversionassetspaginator)
         """
 
 
 class ListPackageVersionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListPackageVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersions)[Show boto3-stubs documentation](./paginators.md#listpackageversionspaginator)
     """
 
     def paginate(
         self,
         domain: str,
         repository: str,
-        format: Literal["npm", "pypi", "maven", "nuget"],
+        format: PackageFormat,
         package: str,
         domainOwner: str = None,
         namespace: str = None,
-        status: Literal[
-            "Published", "Unfinished", "Unlisted", "Archived", "Disposed", "Deleted"
-        ] = None,
+        status: PackageVersionStatus = None,
         sortBy: Literal["PUBLISHED_TIME"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListPackageVersionsResultTypeDef]:
         """
-        [ListPackageVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersions.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listpackageversionspaginator)
         """
 
 
 class ListPackagesPaginator(Boto3Paginator):
     """
-    [Paginator.ListPackages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackages)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackages)[Show boto3-stubs documentation](./paginators.md#listpackagespaginator)
     """
 
     def paginate(
@@ -125,32 +129,34 @@ class ListPackagesPaginator(Boto3Paginator):
         domain: str,
         repository: str,
         domainOwner: str = None,
-        format: Literal["npm", "pypi", "maven", "nuget"] = None,
+        format: PackageFormat = None,
         namespace: str = None,
         packagePrefix: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListPackagesResultTypeDef]:
         """
-        [ListPackages.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackages.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackages.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listpackagespaginator)
         """
 
 
 class ListRepositoriesPaginator(Boto3Paginator):
     """
-    [Paginator.ListRepositories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositories)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositories)[Show boto3-stubs documentation](./paginators.md#listrepositoriespaginator)
     """
 
     def paginate(
         self, repositoryPrefix: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListRepositoriesResultTypeDef]:
         """
-        [ListRepositories.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositories.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositories.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listrepositoriespaginator)
         """
 
 
 class ListRepositoriesInDomainPaginator(Boto3Paginator):
     """
-    [Paginator.ListRepositoriesInDomain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositoriesInDomain)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositoriesInDomain)[Show boto3-stubs documentation](./paginators.md#listrepositoriesindomainpaginator)
     """
 
     def paginate(
@@ -162,5 +168,6 @@ class ListRepositoriesInDomainPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListRepositoriesInDomainResultTypeDef]:
         """
-        [ListRepositoriesInDomain.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositoriesInDomain.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositoriesInDomain.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listrepositoriesindomainpaginator)
         """
